@@ -1,7 +1,6 @@
-#[macro_use]
-extern crate enum_as_inner;
+use enum_as_inner::EnumAsInner;
 
-#[derive(EnumAsInner)]
+#[derive(Debug, EnumAsInner)]
 enum EmptyTest {}
 
 #[test]
@@ -11,7 +10,7 @@ fn test_empty() {
     assert!(empty.is_none());
 }
 
-#[derive(EnumAsInner)]
+#[derive(Debug, EnumAsInner)]
 enum EmptyParendsTest {
     Empty(),
 }
@@ -21,9 +20,10 @@ fn test_empty_parends() {
     let empty = EmptyParendsTest::Empty();
 
     assert_eq!(empty.as_empty().unwrap(), ());
+    assert_eq!(empty.into_empty().unwrap(), ());
 }
 
-#[derive(EnumAsInner)]
+#[derive(Debug, EnumAsInner)]
 enum OneTest {
     One(u32),
 }
@@ -33,9 +33,10 @@ fn test_one() {
     let empty = OneTest::One(1);
 
     assert_eq!(*empty.as_one().unwrap(), 1);
+    assert_eq!(empty.into_one().unwrap(), 1);
 }
 
-#[derive(EnumAsInner)]
+#[derive(Debug, EnumAsInner)]
 enum MultiTest {
     Multi(u32, u32),
 }
@@ -45,4 +46,5 @@ fn test_multi() {
     let multi = MultiTest::Multi(1, 1);
 
     assert_eq!(multi.as_multi().unwrap(), (&1_u32, &1_u32));
+    assert_eq!(multi.into_multi().unwrap(), (1_u32, 1_u32));
 }
